=== modified file 'NEWS'
--- NEWS	2008-05-16 20:58:44 +0000
+++ NEWS	2008-05-16 21:00:25 +0000
@@ -44,6 +44,26 @@
       (Robert Collins)
 
 
+bzr 1.5 2008-05-16
+------------------
+
+This release of Bazaar includes several updates to the documentation, and fixes
+to prepare for making rich root support the default format. Many bugs have been
+squashed, including fixes to log, bzr+ssh inter-operation with older servers.
+
+  CHANGES:
+
+    * Suppress deprecation warnings when bzrlib is a 'final' release. This way
+      users of packaged software won't be bothered with DeprecationWarnings,
+      but developers and testers will still see them. (John Arbash Meinel)
+
+  DOCUMENTATION:
+
+    * Incorporate feedback from Jelmer Vernooij and Neil Martinsen-Burrell
+      on the plugin and integration chapters of the User Guide.
+      (Ian Clatworthy)
+
+
 bzr 1.5rc1 2008-05-09
 ---------------------
 

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2008-05-08 04:21:01 +0000
+++ bzrlib/commands.py	2008-05-16 16:54:44 +0000
@@ -824,6 +824,11 @@
     import bzrlib.ui
     from bzrlib.ui.text import TextUIFactory
     bzrlib.ui.ui_factory = TextUIFactory()
+     
+    # Is this a final release version? If so, we should suppress warnings
+    if bzrlib.version_info[3] == 'final':
+        from bzrlib import symbol_versioning
+        symbol_versioning.suppress_deprecation_warnings()
     try:
         argv = [a.decode(bzrlib.user_encoding) for a in argv[1:]]
     except UnicodeDecodeError:

=== modified file 'bzrlib/symbol_versioning.py'
--- bzrlib/symbol_versioning.py	2008-05-11 23:49:50 +0000
+++ bzrlib/symbol_versioning.py	2008-05-16 21:00:25 +0000
@@ -331,3 +331,29 @@
                 return self._warn_deprecated(list.pop)
 
     return _DeprecatedList(initial_value)
+
+
+def suppress_deprecation_warnings():
+    """Call this function to suppress all deprecation warnings.
+
+    When this is a final release version, we don't want to annoy users with
+    lots of deprecation warnings. We only want the deprecation warnings when
+    running a dev or release candidate.
+    """
+    import warnings
+    warnings.filterwarnings('ignore', category=DeprecationWarning)
+
+
+def activate_deprecation_warnings():
+    """Call this function to activate deprecation warnings.
+
+    When running in a 'final' release we suppress deprecation warnings.
+    However, the test suite wants to see them. So when running selftest, we
+    re-enable the deprecation warnings.
+
+    Note: warnings that have already been issued under 'ignore' will not be
+    reported after this point. The 'warnings' module has already marked them as
+    handled, so they don't get issued again.
+    """
+    import warnings
+    warnings.filterwarnings('default', category=DeprecationWarning)

